import os
from django.core.management.base import BaseCommand


class Command(BaseCommand):
    help = "Generate an activity_logger.py file with default configurations."

    # Default configuration content
    DEFAULT_LOGGER_CONFIG = """
# Default logger configuration for activity tracking

ACTIVITY_LOGGER = {
    # 'DOWNLOAD_ENABLE' controls whether activity logs can be downloaded.
    # When set to False, downloading activity logs is disabled.
    'DOWNLOAD_ENABLE': False,

    # 'INCLUDE_MODELS' defines the list of model names that will be included for logging activities.
    # Only the models specified here will have their changes tracked in the ActivityLog.
    # Example: ['migrations', 'user', 'group'] will track activities for models related to migrations, users, and groups.
    'INCLUDE_MODELS': ['migrations', 'user', 'group']
}

# 'UPDATED_BY' is the name of the field in the model that stores the user responsible for updating the record.
# This field will be used to track who last updated the instance. By default, it is 'updated_by'.
UPDATED_BY = 'updated_by'

# 'CREATED_BY' is the name of the field in the model that stores the user responsible for creating the record.
# This field will be used to track who initially created the instance. By default, it is 'created_by'.
CREATED_BY = 'created_by'

"""

    def handle(self, *args, **kwargs):
        filename = "activity_logger.py" 

        # Check if the file already exists
        if os.path.exists(filename):
            self.stdout.write(self.style.WARNING(f"File '{filename}' already exists."))
            return

        # Create the configuration file
        try:
            with open(filename, "w") as file:
                file.write(self.DEFAULT_LOGGER_CONFIG)
            self.stdout.write(self.style.SUCCESS(f"File '{filename}' created successfully."))
        except Exception as e:
            self.stdout.write(self.style.ERROR(f"An error occurred: {e}"))
