from rest_framework import generics, status
from rest_framework.response import Response
from rest_framework.decorators import api_view
from django.utils.dateparse import parse_datetime
from .models import ActivityLog
from .serializers import ActivityLogSerializer
from datetime import datetime

# Retrieve the entire activity log list
class ActivityLogListView(generics.ListAPIView):
    queryset = ActivityLog.objects.all()
    serializer_class = ActivityLogSerializer


# Retrieve activity logs filtered by an identifier (user, model, etc.)
class ActivityLogFilteredView(generics.ListAPIView):
    serializer_class = ActivityLogSerializer

    def get_queryset(self):
        queryset = ActivityLog.objects.all()
        user_id = self.request.query_params.get('user', None)
        model_name = self.request.query_params.get('model', None)
        
        if user_id:
            queryset = queryset.filter(created_by_id=user_id)
        if model_name:
            queryset = queryset.filter(model_name=model_name)
        
        return queryset


# Delete activity logs within a specified date range
@api_view(['DELETE'])
def delete_logs_in_date_range(request):
    start_date = request.query_params.get('start_date')
    end_date = request.query_params.get('end_date')
    
    try:
        start_date = parse_datetime(start_date) if start_date else None
        end_date = parse_datetime(end_date) if end_date else None
    except ValueError:
        return Response(
            {"error": "Invalid date format. Use ISO format (YYYY-MM-DD)."},
            status=status.HTTP_400_BAD_REQUEST
        )

    if not start_date or not end_date:
        return Response(
            {"error": "Please provide both start_date and end_date in the format YYYY-MM-DD."},
            status=status.HTTP_400_BAD_REQUEST
        )

    deleted_count, _ = ActivityLog.objects.filter(created_at__range=(start_date, end_date)).delete()
    return Response({"deleted_count": deleted_count}, status=status.HTTP_204_NO_CONTENT)
